summaryrefslogtreecommitdiffstats
path: root/tdehtml/ecma/kjs_binding.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdehtml/ecma/kjs_binding.cpp')
-rw-r--r--tdehtml/ecma/kjs_binding.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/tdehtml/ecma/kjs_binding.cpp b/tdehtml/ecma/kjs_binding.cpp
index 0a0a2da47..c3dd39255 100644
--- a/tdehtml/ecma/kjs_binding.cpp
+++ b/tdehtml/ecma/kjs_binding.cpp
@@ -395,18 +395,18 @@ Value KJS::getLiveConnectValue(KParts::LiveConnectExtension *lc, const TQString
}
}
/* only with gcc > 3.4 KDE_NO_EXPORT */
EmbedLiveConnect::EmbedLiveConnect(KParts::LiveConnectExtension *lc, UString n, KParts::LiveConnectExtension::Type t, int id)
: m_liveconnect (lc), name(n), objtype(t), objid(id)
{}
/* only with gcc > 3.4 KDE_NO_EXPORT */
EmbedLiveConnect::~EmbedLiveConnect() {
if (m_liveconnect)
m_liveconnect->unregister(objid);
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
Value EmbedLiveConnect::get(ExecState *, const Identifier & prop) const
{
if (m_liveconnect) {
@@ -419,19 +419,19 @@ Value EmbedLiveConnect::get(ExecState *, const Identifier & prop) const
return Undefined();
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
void EmbedLiveConnect::put(ExecState * exec, const Identifier &prop, const Value & value, int)
{
if (m_liveconnect)
m_liveconnect->put(objid, prop.qstring(), value.toString(exec).qstring());
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
bool EmbedLiveConnect::implementsCall() const {
return objtype == KParts::LiveConnectExtension::TypeFunction;
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
Value EmbedLiveConnect::call(ExecState *exec, Object&, const List &args)
{
if (m_liveconnect) {
@@ -447,17 +447,17 @@ Value EmbedLiveConnect::call(ExecState *exec, Object&, const List &args)
return Undefined();
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
bool EmbedLiveConnect::toBoolean(ExecState *) const {
return true;
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
Value EmbedLiveConnect::toPrimitive(ExecState *exec, Type) const {
return String(toString(exec));
}
-KDE_NO_EXPORT
+TDE_NO_EXPORT
UString EmbedLiveConnect::toString(ExecState *) const {
TQString str;
const char *type = objtype == KParts::LiveConnectExtension::TypeFunction ? "Function" : "Object";
@@ -395,18 +395,18 @@ Value KJS::getLiveConnectValue(KParts::LiveConnectExtension *lc, const TQString
}
}
-/* only with gcc > 3.4 KDE_NO_EXPORT */
+/* only with gcc > 3.4 TDE_NO_EXPORT */
EmbedLiveConnect::EmbedLiveConnect(KParts::LiveConnectExtension *lc, UString n, KParts::LiveConnectExtension::Type t, int id)
: m_liveconnect (lc), name(n), objtype(t), objid(id)
@@ -395,18 +395,18 @@ Value KJS::getLiveConnectValue(KParts::LiveConnectExtension *lc, const TQString
: m_liveconnect (lc), name(n), objtype(t), objid(id)
{}
-/* only with gcc > 3.4 KDE_NO_EXPORT */
+/* only with gcc > 3.4 TDE_NO_EXPORT */
EmbedLiveConnect::~EmbedLiveConnect() {
if (m_liveconnect)